@@ -23,7 +23,7 @@ package main
 
 import (
 	"fmt"
-	"io/ioutil"
+	"io"
 	"os"
 	"time"
 
@@ -83,7 +83,7 @@ func main() {
 	}
 	// called via "symfony composer"?
 	if len(args) >= 2 && args[1] == "composer" {
-		res := php.Composer("", args[2:], getCliExtraEnv(), os.Stdout, os.Stderr, ioutil.Discard, zerolog.Nop())
+		res := php.Composer("", args[2:], getCliExtraEnv(), os.Stdout, os.Stderr, io.Discard, zerolog.Nop())
 		terminal.Eprintln(res.Error())
 		os.Exit(res.ExitCode())
 	}
@@ -107,10 +107,16 @@ func main() {
 	}
 	cmds = append(cmds, psh.Commands...)
 	console.HelpPrinter = psh.WrapHelpPrinter()
+	c1 := "#0057B7"
+	c2 := "#FFDD00"
+	if os.Getenv("COLORTERM") != "truecolor" {
+		c1 = "blue"
+		c2 = "yellow"
+	}
 	app := &console.Application{
 		Name:          "Symfony CLI",
 		Usage:         "Symfony CLI helps developers manage projects, from local code to remote infrastructure",
-		Copyright:     fmt.Sprintf("(c) 2021-%d Fabien Potencier <bg=#0057B7;fg=#FFDD00>#StandWith</><bg=#FFDD00;fg=#0057B7>Ukraine</> <href=https://sf.to/ukraine>Support Ukraine</>", time.Now().Year()),
+		Copyright:     fmt.Sprintf("(c) 2021-%d Fabien Potencier <bg=%s;fg=%s>#StandWith</><bg=%s;fg=%s>Ukraine</>", time.Now().Year(), c1, c2, c2, c1),
 		FlagEnvPrefix: []string{"SYMFONY", "PLATFORM"},
 		Commands:      cmds,
 		Action: func(ctx *console.Context) error {
